==> 4.3.zip: retropie-setup/scriptmodules/emulators/scummvm-sdl1.sh <==
#!/usr/bin/env bash

# This file is part of The RetroPie Project
#
# The RetroPie Project is the legal property of its developers, whose names are
# too numerous to list here. Please refer to the COPYRIGHT.md file distributed with this source.
#
# See the LICENSE.md file at the top-level directory of this distribution and
# at https://raw.githubusercontent.com/RetroPie/RetroPie-Setup/master/LICENSE.md
#

rp_module_id="scummvm-sdl1"
rp_module_desc="ScummVM - built with legacy SDL1 support."
rp_module_help="Copy your ScummVM games to $romdir/scummvm"
rp_module_licence="GPL2 https://raw.githubusercontent.com/scummvm/scummvm/master/COPYING"
rp_module_section="opt"
rp_module_flags="dispmanx !mali !x11"

function depends_scummvm-sdl1() {
    depends_scummvm
}

function sources_scummvm-sdl1() {
    sources_scummvm
    gitPullOrClone "$md_build" https://github.com/scummvm/scummvm.git "branch-1-9"
    if isPlatform "rpi"; then
        applyPatch rpi-sdl1.diff <<\_EOF_
--- a/configure
+++ b/configure
@@ -2807,7 +2807,7 @@ if test -n "$_host"; then
 			# We prefer SDL2 on the Raspberry Pi: acceleration now depends on it
 			# since SDL2 manages dispmanx/GLES2 very well internally.
 			# SDL1 is bit-rotten on this platform.
-			_sdlconfig=sdl2-config
+			_sdlconfig=sdl-config
 			# OpenGL ES support is mature enough as to be the best option on
 			# the Raspberry Pi, so it's enabled by default.
 			# The Raspberry Pi always supports OpenGL ES 2.0 contexts, thus we
_EOF_
    fi
}

function build_scummvm-sdl1() {
    build_scummvm
}

function install_scummvm-sdl1() {
    install_scummvm
}

function configure_scummvm-sdl1() {
    configure_scummvm
}

==> 4.8.zip: retropie-setup/scriptmodules/emulators/scummvm-sdl1.sh <==
#!/usr/bin/env bash

# This file is part of The RetroPie Project
#
# The RetroPie Project is the legal property of its developers, whose names are
# too numerous to list here. Please refer to the COPYRIGHT.md file distributed with this source.
#
# See the LICENSE.md file at the top-level directory of this distribution and
# at https://raw.githubusercontent.com/RetroPie/RetroPie-Setup/master/LICENSE.md
#

rp_module_id="scummvm-sdl1"
rp_module_desc="ScummVM - built with legacy SDL1 support."
rp_module_help="Copy your ScummVM games to $romdir/scummvm"
rp_module_licence="GPL2 https://raw.githubusercontent.com/scummvm/scummvm/master/COPYING"
rp_module_repo="git https://github.com/scummvm/scummvm.git v2.5.0"
rp_module_section="opt"
rp_module_flags="sdl1 !mali !x11"

function depends_scummvm-sdl1() {
    depends_scummvm
}

function sources_scummvm-sdl1() {
    # sources_scummvm() expects $md_data to be ../scummvm
    # the following only modifies $md_data for the function call
    md_data="$(dirname $md_data)/scummvm" sources_scummvm
    if isPlatform "rpi"; then
        if isPlatform "kms"; then
            applyPatch "$md_data/01_rpi_kms_sdl1.diff"
        else
            applyPatch "$md_data/01_rpi_sdl1.diff"
        fi
    fi
}

function build_scummvm-sdl1() {
    build_scummvm
}

function install_scummvm-sdl1() {
    install_scummvm
}

function configure_scummvm-sdl1() {
    # use dispmanx by default on rpi with fkms
    isPlatform "dispmanx" && ! isPlatform "videocore" && setBackend "$md_id" "dispmanx"
    configure_scummvm
}
